@@ -6,13 +6,7 @@ use Type::Library -base, -declare => qw( Uri Iri Namespace NamespaceMap );
 use Types::Standard qw( HashRef InstanceOf );
 use Types::URI qw();
 
-my $HalUri     = InstanceOf['Data::HAL::URI'];
-my $AtteanIRI  = InstanceOf['Attean::IRI'];
-my $TrineNS    = InstanceOf['RDF::Trine::Namespace'];
-my $TrineNSMap = InstanceOf['RDF::Trine::NamespaceMap'];
-my $TrineNode  = InstanceOf['RDF::Trine::Node::Resource'];
-
-our $VERSION = '1.09_03';
+our $VERSION = '1.02';
 
 =head1 NAME
 
@@ -35,9 +29,8 @@ Types::Namespace - type constraints for dealing with namespaces
 
 =head1 DESCRIPTION
 
-Types::Namespace is a type constraint library suitable for use with
-L<Moo>/L<Moose> attributes, L<Kavorka> sub signatures, and so
-forth. It builds on L<Types::URI>.
+L<Types::URI> is a type constraint library suitable for use with
+L<Moo>/L<Moose> attributes, L<Kavorka> sub signatures, and so forth.
 
 =head1 TYPES
 
@@ -47,15 +40,13 @@ forth. It builds on L<Types::URI>.
 
 A class type for L<URI::Namespace>.
 
-Can coerce from L<URI>, L<IRI>, L<Path::Tiny>, L<Attean::IRI>,
-L<RDF::Trine::Namespace>, L<RDF::Trine::Node::Resource> and strings.
+Can coerce from L<URI>, L<IRI>, L<Path::Tiny>, and strings.
 
 =item C<< NamespaceMap >>
 
 A class type for L<URI::NamespaceMap>.
 
-Can coerce from a hashref of C<< prefix => URI >> pairs and from
-L<RDF::Trine::NamespaceMap>.
+Can coerce from a hashref of C<< prefix => URI >> pairs.
 
 =item C<< Uri >>, C<< Iri >>
 
@@ -93,10 +84,6 @@ __PACKAGE__->add_type(
 	parent     => InstanceOf['URI::Namespace'],
 	coercion   => [
 		Iri->coercibles ,=> q{ "URI::Namespace"->new($_) },
-		$AtteanIRI      ,=> q{ "URI::Namespace"->new($_->as_string) },
-		$HalUri         ,=> q{ "URI::Namespace"->new($_->as_string) },
-      $TrineNode      ,=> q{ "URI::Namespace"->new($_->as_string) },
-      $TrineNS        ,=> q{ "URI::Namespace"->new($_->as_string) },
 	],
 );
 
@@ -104,8 +91,7 @@ __PACKAGE__->add_type(
 	name       => NamespaceMap,
 	parent     => InstanceOf['URI::NamespaceMap'],
 	coercion   => [
-		HashRef     ,=> q{ "URI::NamespaceMap"->new(namespace_map => $_) },
-      $TrineNSMap ,=> q{ do { my $map = $_; my %hash = map { $_ => $map->namespace_uri($_)->uri_value } $map->list_prefixes ; "URI::NamespaceMap"->new(namespace_map => \%hash) } }
+		HashRef ,=> q{ "URI::NamespaceMap"->new(namespace_map => $_) }
 	],
 );
 
